@@ -2,7 +2,7 @@
 A TiddlyWeb plugin providing a multi-user TiddlyWiki environment.
 """
 
-__version__ = '0.20.1'
+__version__ = '0.20.2'
 
 
 def init(config):
@@ -11,7 +11,7 @@ def init(config):
     import tiddlywebwiki.manage
     import tiddlywebplugins.status
     import tiddlywebplugins.atom
-    import differ
+    import tiddlywebplugins.differ
     from tiddlyweb.util import merge_config
     from tiddlywebwiki.config import config as twwconfig
 
@@ -19,4 +19,4 @@ def init(config):
     tiddlywebwiki.manage.init(config)
     tiddlywebplugins.status.init(config)
     tiddlywebplugins.atom.init(config)
-    differ.init(config)
+    tiddlywebplugins.differ.init(config)
